import { Address } from '@solana/addresses';
import type { Commitment, IRpcApiMethods, RpcResponse, Slot } from '@solana/rpc-types';
import { AccountInfoBase, AccountInfoWithBase58Bytes, AccountInfoWithBase58EncodedData, AccountInfoWithBase64EncodedData, AccountInfoWithBase64EncodedZStdCompressedData, AccountInfoWithJsonData, DataSlice } from './common.js';
type GetAccountInfoApiResponseBase = RpcResponse<AccountInfoBase | null>;
type NestInRpcResponseOrNull<T> = Readonly<{
    value: T | null;
}>;
type GetAccountInfoApiCommonConfig = Readonly<{
    commitment?: Commitment;
    minContextSlot?: Slot;
}>;
type GetAccountInfoApiSliceableCommonConfig = Readonly<{
    dataSlice?: DataSlice;
}>;
export interface GetAccountInfoApi extends IRpcApiMethods {
    /**
     * Returns all information associated with the account of provided public key
     */
    getAccountInfo(address: Address, config: GetAccountInfoApiCommonConfig & GetAccountInfoApiSliceableCommonConfig & Readonly<{
        encoding: 'base64';
    }>): GetAccountInfoApiResponseBase & NestInRpcResponseOrNull<AccountInfoWithBase64EncodedData>;
    getAccountInfo(address: Address, config: GetAccountInfoApiCommonConfig & GetAccountInfoApiSliceableCommonConfig & Readonly<{
        encoding: 'base64+zstd';
    }>): GetAccountInfoApiResponseBase & NestInRpcResponseOrNull<AccountInfoWithBase64EncodedZStdCompressedData>;
    getAccountInfo(address: Address, config: GetAccountInfoApiCommonConfig & Readonly<{
        encoding: 'jsonParsed';
    }>): GetAccountInfoApiResponseBase & NestInRpcResponseOrNull<AccountInfoWithJsonData>;
    getAccountInfo(address: Address, config: GetAccountInfoApiCommonConfig & GetAccountInfoApiSliceableCommonConfig & Readonly<{
        encoding: 'base58';
    }>): GetAccountInfoApiResponseBase & NestInRpcResponseOrNull<AccountInfoWithBase58EncodedData>;
    getAccountInfo(address: Address, config?: GetAccountInfoApiCommonConfig): GetAccountInfoApiResponseBase & NestInRpcResponseOrNull<AccountInfoWithBase58Bytes>;
}
export {};
//# sourceMappingURL=getAccountInfo.d.ts.map